@@ -327,8 +327,7 @@ namespace giac {
   bool check_vect_38(const std::string & s);
   // check value type for storing value in s using 38 compatibility mode
   bool check_sto_38(gen & value,const char * s);
-  extern int (*sto_38)(const gen & value,const char * name_space,const char * idname,gen indice,gen & error,GIAC_CONTEXT);
-  extern int (*rcl_38)(gen & value,const char * name_space,const char * idname,gen indice,bool at_of,GIAC_CONTEXT);
+  extern bool (*storcl_38)(gen & value,const char * name_space,const char * idname,gen indice,bool at_of,GIAC_CONTEXT, gen const *sto,bool OnlyLocal);
   extern int (*is_known_name_38)(const char * name_space,const char * idname);
   extern gen (*of_pointer_38)(const void * appptr,const void * varptr,const gen & args);
   extern gen_op_context * interactive_op_tab;
@@ -544,6 +543,11 @@ namespace giac {
   extern const double deg2rad_d;
   extern const gen & rad2deg_g;
   extern const gen & deg2rad_g;
+  //grad
+  extern const double rad2grad_d;
+  extern const double grad2rad_d;
+  extern const gen & rad2grad_g;
+  extern const gen & grad2rad_g;
 
 #if defined(GIAC_GENERIC_CONSTANTS) // || (defined(VISUALC) && !defined(RTOS_THREADX)) || defined(__x86_64__)
   extern gen cst_two_pi;
@@ -574,6 +578,9 @@ namespace giac {
   extern gen minus_tan_5pi_12;
   extern gen rad2deg_e;
   extern gen deg2rad_e;
+  //grad
+  extern gen rad2grad_e;
+  extern gen grad2rad_e;
   extern const gen * const table_cos[];
   extern const gen * const table_tan[];
 #else
@@ -767,6 +774,19 @@ namespace giac {
   extern const alias_gen alias_deg2rad_e;
   extern const gen & deg2rad_e ;
 
+  //grad
+  extern const alias_gen alias_rad2grad_e_tab[];
+  extern const alias_ref_vecteur rad2grad_e_refv;
+  extern const alias_ref_symbolic rad2grad_e_symb;
+  extern const alias_gen alias_rad2grad_e;
+  extern const gen & rad2grad_e;
+
+  extern const alias_gen alias_grad2rad_e_tab[];
+  extern const alias_ref_vecteur grad2rad_e_refv;
+  extern const alias_ref_symbolic grad2rad_e_symb;
+  extern const alias_gen alias_grad2rad_e;
+  extern const gen & grad2rad_e;
+
 
   extern const gen * const * table_cos;
   extern const gen * const * table_tan;
